@@ -33,8 +33,8 @@
 #include <dix-config.h>
 #endif
 
-#include <stddef.h> /* For NULL */
-#include <limits.h> /* For CHAR_BIT */
+#include <stddef.h>             /* For NULL */
+#include <limits.h>             /* For CHAR_BIT */
 #include <assert.h>
 #include <X11/Xatom.h>
 #ifdef __APPLE__
@@ -67,9 +67,10 @@ extern Bool no_configure_window;
     return atom;                                                \
   }
 
-DEFINE_ATOM_HELPER (xa_native_window_id, "_NATIVE_WINDOW_ID")
+DEFINE_ATOM_HELPER(xa_native_window_id, "_NATIVE_WINDOW_ID")
 
 static Bool windows_hidden;
+
 // TODO - abstract xp functions
 
 #ifdef __APPLE__
@@ -78,56 +79,64 @@ static Bool windows_hidden;
 #define MAKE_WINDOW_ID(x)		((xp_window_id)((size_t)(x)))
 
 void
-RootlessNativeWindowStateChanged (WindowPtr pWin, unsigned int state)
+RootlessNativeWindowStateChanged(WindowPtr pWin, unsigned int state)
 {
-  RootlessWindowRec *winRec;
+    RootlessWindowRec *winRec;
 
-  if (pWin == NULL) return;
+    if (pWin == NULL)
+        return;
 
-  winRec = WINREC (pWin);
-  if (winRec == NULL) return;
+    winRec = WINREC(pWin);
+    if (winRec == NULL)
+        return;
 
-  winRec->is_offscreen = ((state & XP_WINDOW_STATE_OFFSCREEN) != 0);
-  winRec->is_obscured = ((state & XP_WINDOW_STATE_OBSCURED) != 0);
-  pWin->rootlessUnhittable = winRec->is_offscreen;
+    winRec->is_offscreen = ((state & XP_WINDOW_STATE_OFFSCREEN) != 0);
+    winRec->is_obscured = ((state & XP_WINDOW_STATE_OBSCURED) != 0);
+    pWin->rootlessUnhittable = winRec->is_offscreen;
 }
 
-void RootlessNativeWindowMoved (WindowPtr pWin) {
+void
+RootlessNativeWindowMoved(WindowPtr pWin)
+{
     xp_box bounds;
     int sx, sy, err;
     XID vlist[2];
     Mask mask;
     ClientPtr pClient;
     RootlessWindowRec *winRec;
-    
+
     winRec = WINREC(pWin);
-    
-    if (xp_get_window_bounds (MAKE_WINDOW_ID(winRec->wid), &bounds) != Success) return;
-    
+
+    if (xp_get_window_bounds(MAKE_WINDOW_ID(winRec->wid), &bounds) != Success)
+        return;
+
     sx = pWin->drawable.pScreen->x + darwinMainScreenX;
     sy = pWin->drawable.pScreen->y + darwinMainScreenY;
-    
+
     /* Fake up a ConfigureWindow packet to resize the window to the current bounds. */
     vlist[0] = (INT16) bounds.x1 - sx;
     vlist[1] = (INT16) bounds.y1 - sy;
     mask = CWX | CWY;
-    
+
     /* pretend we're the owner of the window! */
-    err = dixLookupClient(&pClient, pWin->drawable.id, serverClient, DixUnknownAccess);
-    if(err != Success) {
-        ErrorF("RootlessNativeWindowMoved(): Failed to lookup window: 0x%x\n", (unsigned int)pWin->drawable.id);
+    err =
+        dixLookupClient(&pClient, pWin->drawable.id, serverClient,
+                        DixUnknownAccess);
+    if (err != Success) {
+        ErrorF("RootlessNativeWindowMoved(): Failed to lookup window: 0x%x\n",
+               (unsigned int) pWin->drawable.id);
         return;
     }
-    
+
     /* Don't want to do anything to the physical window (avoids 
-     notification-response feedback loops) */
-    
+       notification-response feedback loops) */
+
     no_configure_window = TRUE;
-    ConfigureWindow (pWin, mask, vlist, pClient);
+    ConfigureWindow(pWin, mask, vlist, pClient);
     no_configure_window = FALSE;
 }
 
-#endif /* __APPLE__ */
+#endif                          /* __APPLE__ */
 
 /*
  * RootlessCreateWindow
@@ -166,7 +175,6 @@ RootlessCreateWindow(WindowPtr pWin)
     return result;
 }
 
-
 /*
  * RootlessDestroyFrame
  *  Destroy the physical window associated with the given window.
@@ -179,7 +187,6 @@ RootlessDestroyFrame(WindowPtr pWin, RootlessWindowPtr winRec)
     SETWINREC(pWin, NULL);
 }
 
-
 /*
  * RootlessDestroyWindow
  *  Destroy the physical window associated with the given window.
@@ -201,8 +208,6 @@ RootlessDestroyWindow(WindowPtr pWin)
     return result;
 }
 
-
-
 static Bool
 RootlessGetShape(WindowPtr pWin, RegionPtr pShape)
 {
@@ -219,12 +224,12 @@ RootlessGetShape(WindowPtr pWin, RegionPtr pShape)
     return TRUE;
 }
 
-
 /*
  * RootlessReshapeFrame
  *  Set the frame shape.
  */
-static void RootlessReshapeFrame(WindowPtr pWin)
+static void
+RootlessReshapeFrame(WindowPtr pWin)
 {
     RootlessWindowRec *winRec = WINREC(pWin);
     RegionRec newShape;
@@ -248,7 +253,8 @@ static void RootlessReshapeFrame(WindowPtr pWin)
                      RegionNumRects(&newShape),
                      newShape.extents.x1, newShape.extents.y1,
                      newShape.extents.x2, newShape.extents.y2);
-    } else {
+    }
+    else {
         RL_DEBUG_MSG("no shape ");
     }
 #endif
@@ -259,7 +265,6 @@ static void RootlessReshapeFrame(WindowPtr pWin)
         RegionUninit(&newShape);
 }
 
-
 /*
  * RootlessSetShape
  *  Shape is usually set before a window is mapped and the window will
@@ -278,8 +283,6 @@ RootlessSetShape(WindowPtr pWin, int kind)
     RootlessReshapeFrame(pWin);
 }
 
-
-
 /* Disallow ParentRelative background on top-level windows
    because the root window doesn't really have the right background.
  */
@@ -299,6 +302,7 @@ RootlessChangeWindowAttributes(WindowPtr pWin, unsigned long vmask)
         // disallow ParentRelative background state
         if (pWin->backgroundState == ParentRelative) {
             XID pixel = 0;
+
             ChangeWindowAttributes(pWin, CWBackPixel, &pixel, serverClient);
         }
     }
@@ -307,7 +311,6 @@ RootlessChangeWindowAttributes(WindowPtr pWin, unsigned long vmask)
     return result;
 }
 
-
 /*
  * RootlessPositionWindow
  *  This is a hook for when DIX moves or resizes a window.
@@ -342,7 +345,6 @@ RootlessPositionWindow(WindowPtr pWin, int x, int y)
     return result;
 }
 
-
 /*
  * RootlessInitializeFrame
  *  Initialize some basic attributes of the frame. Note that winRec
@@ -350,7 +352,7 @@ RootlessPositionWindow(WindowPtr pWin, int x, int y)
  *  valuable.
  */
 static void
-RootlessInitializeFrame(WindowPtr pWin, RootlessWindowRec *winRec)
+RootlessInitializeFrame(WindowPtr pWin, RootlessWindowRec * winRec)
 {
     DrawablePtr d = &pWin->drawable;
     int bw = wBorderWidth(pWin);
@@ -359,8 +361,8 @@ RootlessInitializeFrame(WindowPtr pWin, RootlessWindowRec *winRec)
 
     winRec->x = d->x - bw;
     winRec->y = d->y - bw;
-    winRec->width = d->width + 2*bw;
-    winRec->height = d->height + 2*bw;
+    winRec->width = d->width + 2 * bw;
+    winRec->height = d->height + 2 * bw;
     winRec->borderWidth = bw;
 }
 
@@ -411,8 +413,7 @@ RootlessEnsureFrame(WindowPtr pWin)
     if (!SCREENREC(pScreen)->imp->CreateFrame(winRec, pScreen,
                                               winRec->x + SCREEN_TO_GLOBAL_X,
                                               winRec->y + SCREEN_TO_GLOBAL_Y,
-                                              pShape))
-    {
+                                              pShape)) {
         RL_DEBUG_MSG("implementation failed to create frame!\n");
         free(winRec);
         SETWINREC(pWin, NULL);
@@ -420,7 +421,7 @@ RootlessEnsureFrame(WindowPtr pWin)
     }
 
     if (pWin->drawable.depth == 8)
-      RootlessFlushWindowColormap(pWin);
+        RootlessFlushWindowColormap(pWin);
 
     if (pShape != NULL)
         RegionUninit(&shape);
@@ -428,7 +429,6 @@ RootlessEnsureFrame(WindowPtr pWin)
     return winRec;
 }
 
-
 /*
  * RootlessRealizeWindow
  *  The frame is usually created here and not in CreateWindow so that
@@ -458,21 +458,23 @@ RootlessRealizeWindow(WindowPtr pWin)
         // This might have been set before the window was mapped.
         if (pWin->backgroundState == ParentRelative) {
             XID pixel = 0;
+
             ChangeWindowAttributes(pWin, CWBackPixel, &pixel, serverClient);
         }
     }
 
-    if (!IsRoot(pWin)) HUGE_ROOT(pWin);
+    if (!IsRoot(pWin))
+        HUGE_ROOT(pWin);
     SCREEN_UNWRAP(pScreen, RealizeWindow);
     result = pScreen->RealizeWindow(pWin);
     SCREEN_WRAP(pScreen, RealizeWindow);
-    if (!IsRoot(pWin)) NORMAL_ROOT(pWin);
+    if (!IsRoot(pWin))
+        NORMAL_ROOT(pWin);
 
     RL_DEBUG_MSG("realizewindow end\n");
     return result;
 }
 
-
 /*
  * RootlessFrameForWindow
  *  Returns the frame ID for the physical window displaying the given window. 
@@ -500,7 +502,6 @@ RootlessFrameForWindow(WindowPtr pWin, Bool create)
     return winRec->wid;
 }
 
-
 /*
  * RootlessUnrealizeWindow
  *  Unmap the physical window.
@@ -530,7 +531,6 @@ RootlessUnrealizeWindow(WindowPtr pWin)
     return result;
 }
 
-
 /*
  * RootlessReorderWindow
  *  Reorder the frame associated with the given window so that it's
@@ -541,7 +541,8 @@ RootlessReorderWindow(WindowPtr pWin)
 {
     RootlessWindowRec *winRec = WINREC(pWin);
 
-    if (pWin->realized && winRec != NULL && !winRec->is_reorder_pending && !windows_hidden) {
+    if (pWin->realized && winRec != NULL && !winRec->is_reorder_pending &&
+        !windows_hidden) {
         WindowPtr newPrevW;
         RootlessWindowRec *newPrev;
         RootlessFrameID newPrevID;
@@ -566,7 +567,9 @@ RootlessReorderWindow(WindowPtr pWin)
          */
 
         newPrevW = pWin->prevSib;
-        while (newPrevW && (WINREC(newPrevW) == NULL || !newPrevW->realized || newPrevW->rootlessUnhittable != pWin->rootlessUnhittable))
+        while (newPrevW &&
+               (WINREC(newPrevW) == NULL || !newPrevW->realized ||
+                newPrevW->rootlessUnhittable != pWin->rootlessUnhittable))
             newPrevW = newPrevW->prevSib;
 
         newPrev = newPrevW != NULL ? WINREC(newPrevW) : NULL;
@@ -583,7 +586,6 @@ RootlessReorderWindow(WindowPtr pWin)
     }
 }
 
-
 /*
  * RootlessRestackWindow
  *  This is a hook for when DIX changes the window stacking order.
@@ -625,7 +627,8 @@ RootlessRestackWindow(WindowPtr pWin, WindowPtr pOldNextSib)
 // Globals needed during window resize and move.
 static pointer gResizeDeathBits = NULL;
 static int gResizeDeathCount = 0;
-static PixmapPtr gResizeDeathPix[2] = {NULL, NULL};
+static PixmapPtr gResizeDeathPix[2] = { NULL, NULL };
+
 static BoxRec gResizeDeathBounds[2];
 static CopyWindowProcPtr gResizeOldCopyWindowProc = NULL;
 
@@ -635,8 +638,7 @@ static CopyWindowProcPtr gResizeOldCopyWindowProc = NULL;
  *  top-level windows.
  */
 static void
-RootlessNoCopyWindow(WindowPtr pWin, DDXPointRec ptOldOrg,
-                     RegionPtr prgnSrc)
+RootlessNoCopyWindow(WindowPtr pWin, DDXPointRec ptOldOrg, RegionPtr prgnSrc)
 {
     // some code expects the region to be translated
     int dx = ptOldOrg.x - pWin->drawable.x;
@@ -647,7 +649,6 @@ RootlessNoCopyWindow(WindowPtr pWin, DDXPointRec ptOldOrg,
     RegionTranslate(prgnSrc, -dx, -dy);
 }
 
-
 /*
  * RootlessResizeCopyWindow
  *  CopyWindow used during ResizeWindow for gravity moves. Based on
@@ -660,8 +661,8 @@ RootlessResizeCopyWindow(WindowPtr pWin, DDXPointRec ptOldOrg,
                          RegionPtr prgnSrc)
 {
     ScreenPtr pScreen = pWin->drawable.pScreen;
-    RegionRec   rgnDst;
-    int         dx, dy;
+    RegionRec rgnDst;
+    int dx, dy;
 
     RL_DEBUG_MSG("resizecopywindowFB start (win 0x%x) ", pWin);
 
@@ -683,7 +684,7 @@ RootlessResizeCopyWindow(WindowPtr pWin, DDXPointRec ptOldOrg,
     if (gResizeDeathCount == 1) {
         /* Simple case, we only have a single source pixmap. */
 
-        fbCopyRegion(&gResizeDeathPix[0]->drawable,
+        miCopyRegion(&gResizeDeathPix[0]->drawable,
                      &pScreen->GetWindowPixmap(pWin)->drawable, 0,
                      &rgnDst, dx, dy, fbCopyWindowProc, 0, 0);
     }
@@ -699,7 +700,7 @@ RootlessResizeCopyWindow(WindowPtr pWin, DDXPointRec ptOldOrg,
             RegionNull(&clipped);
             RegionIntersect(&rgnDst, &clip, &clipped);
 
-            fbCopyRegion(&gResizeDeathPix[i]->drawable,
+            miCopyRegion(&gResizeDeathPix[i]->drawable,
                          &pScreen->GetWindowPixmap(pWin)->drawable, 0,
                          &clipped, dx, dy, fbCopyWindowProc, 0, 0);
 
@@ -716,7 +717,6 @@ RootlessResizeCopyWindow(WindowPtr pWin, DDXPointRec ptOldOrg,
     RL_DEBUG_MSG("resizecopywindowFB end\n");
 }
 
-
 /*
  * RootlessCopyWindow
  *  Update *new* location of window. Old location is redrawn with
@@ -728,8 +728,8 @@ void
 RootlessCopyWindow(WindowPtr pWin, DDXPointRec ptOldOrg, RegionPtr prgnSrc)
 {
     ScreenPtr pScreen = pWin->drawable.pScreen;
-    RegionRec   rgnDst;
-    int         dx, dy;
+    RegionRec rgnDst;
+    int dx, dy;
     BoxPtr extents;
     int area;
 
@@ -750,8 +750,7 @@ RootlessCopyWindow(WindowPtr pWin, DDXPointRec ptOldOrg, RegionPtr prgnSrc)
     /* If the area exceeds threshold, use the implementation's
        accelerated version. */
     if (area > rootless_CopyWindow_threshold &&
-        SCREENREC(pScreen)->imp->CopyWindow)
-    {
+        SCREENREC(pScreen)->imp->CopyWindow) {
         RootlessWindowRec *winRec;
         WindowPtr top;
 
@@ -774,20 +773,19 @@ RootlessCopyWindow(WindowPtr pWin, DDXPointRec ptOldOrg, RegionPtr prgnSrc)
 
         SCREENREC(pScreen)->imp->CopyWindow(winRec->wid,
                                             RegionNumRects(&rgnDst),
-                                            RegionRects(&rgnDst),
-                                            dx, dy);
+                                            RegionRects(&rgnDst), dx, dy);
     }
     else {
         RootlessStartDrawing(pWin);
 
-        fbCopyRegion((DrawablePtr) pWin, (DrawablePtr) pWin,
+        miCopyRegion((DrawablePtr) pWin, (DrawablePtr) pWin,
                      0, &rgnDst, dx, dy, fbCopyWindowProc, 0, 0);
 
         /* prgnSrc has been translated to dst position */
         RootlessDamageRegion(pWin, prgnSrc);
     }
 
-out:
+ out:
     RegionUninit(&rgnDst);
     fbValidateDrawable(&pWin->drawable);
 
@@ -796,7 +794,6 @@ out:
     RL_DEBUG_MSG("copywindowFB end\n");
 }
 
-
 /*
  * Window resize procedures
  */
@@ -806,7 +803,6 @@ enum {
     HEIGHT_SMALLER = 2,
 };
 
-
 /*
  * ResizeWeighting
  *  Choose gravity to avoid local copies. Do that by looking for
@@ -835,7 +831,6 @@ ResizeWeighting(int oldX1, int oldY1, int oldX2, int oldY2, int oldBW,
 #endif
 }
 
-
 /*
  * StartFrameResize
  *  Prepare to resize a top-level window. The old window's pixels are
@@ -871,8 +866,7 @@ StartFrameResize(WindowPtr pWin, Bool gravity,
 
     RL_DEBUG_MSG("RESIZE TOPLEVEL WINDOW with gravity %i ", gravity);
     RL_DEBUG_MSG("%d %d %d %d %d   %d %d %d %d %d\n",
-                 oldX, oldY, oldW, oldH, oldBW,
-                 newX, newY, newW, newH, newBW);
+                 oldX, oldY, oldW, oldH, oldBW, newX, newY, newW, newH, newBW);
 
     RootlessRedisplay(pWin);
 
@@ -903,8 +897,8 @@ StartFrameResize(WindowPtr pWin, Bool gravity,
         need_window_source = TRUE;
 
         /* These comparisons were chosen to avoid setting bits when the sizes
-        are the same. (So the fastest case automatically gets taken when
-        dimensions are unchanging.) */
+           are the same. (So the fastest case automatically gets taken when
+           dimensions are unchanging.) */
 
         if (newW < oldW)
             code |= WIDTH_SMALLER;
@@ -955,28 +949,33 @@ StartFrameResize(WindowPtr pWin, Bool gravity,
             copy_rect_width = copy_rect.x2 - copy_rect.x1;
             copy_rect_height = copy_rect.y2 - copy_rect.y1;
             copy_rowbytes = ((copy_rect_width * Bpp) + 31) & ~31;
-            gResizeDeathBits = malloc(copy_rowbytes
-                                      * copy_rect_height);
+            gResizeDeathBits = malloc(copy_rowbytes * copy_rect_height);
 
             if (copy_rect_width * copy_rect_height >
-                        rootless_CopyBytes_threshold &&
-                SCREENREC(pScreen)->imp->CopyBytes)
-            {
-                SCREENREC(pScreen)->imp->CopyBytes(
-                    copy_rect_width * Bpp, copy_rect_height,
-                    ((char *) winRec->pixelData)
-                    + ((copy_rect.y1 - oldY) * winRec->bytesPerRow)
-                    + (copy_rect.x1 - oldX) * Bpp, winRec->bytesPerRow,
-                    gResizeDeathBits, copy_rowbytes);
-            } else {
+                rootless_CopyBytes_threshold &&
+                SCREENREC(pScreen)->imp->CopyBytes) {
+                SCREENREC(pScreen)->imp->CopyBytes(copy_rect_width * Bpp,
+                                                   copy_rect_height,
+                                                   ((char *) winRec->pixelData)
+                                                   +
+                                                   ((copy_rect.y1 -
+                                                     oldY) *
+                                                    winRec->bytesPerRow)
+                                                   + (copy_rect.x1 -
+                                                      oldX) * Bpp,
+                                                   winRec->bytesPerRow,
+                                                   gResizeDeathBits,
+                                                   copy_rowbytes);
+            }
+            else {
                 fbBlt((FbBits *) (winRec->pixelData
-                      + ((copy_rect.y1 - oldY) * winRec->bytesPerRow)
-                      + (copy_rect.x1 - oldX) * Bpp),
+                                  +
+                                  ((copy_rect.y1 - oldY) * winRec->bytesPerRow)
+                                  + (copy_rect.x1 - oldX) * Bpp),
                       winRec->bytesPerRow / sizeof(FbBits), 0,
                       (FbBits *) gResizeDeathBits,
-                      copy_rowbytes / sizeof(FbBits), 0,
-                      copy_rect_width * Bpp, copy_rect_height,
-                      GXcopy, FB_ALLONES, Bpp, 0, 0);
+                      copy_rowbytes / sizeof(FbBits), 0, copy_rect_width * Bpp,
+                      copy_rect_height, GXcopy, FB_ALLONES, Bpp, 0, 0);
             }
 
             gResizeDeathBounds[1] = copy_rect;
@@ -1004,7 +1003,8 @@ StartFrameResize(WindowPtr pWin, Bool gravity,
         memcpy(gResizeDeathBits, winRec->pixelData,
                winRec->bytesPerRow * winRec->height);
 
-        gResizeDeathBounds[0] = (BoxRec) {oldX, oldY, oldX2, oldY2};
+        gResizeDeathBounds[0] = (BoxRec) {
+        oldX, oldY, oldX2, oldY2};
         gResizeDeathPix[0]
             = GetScratchPixmapHeader(pScreen, winRec->width,
                                      winRec->height,
@@ -1041,7 +1041,8 @@ StartFrameResize(WindowPtr pWin, Bool gravity,
        window bits. */
 
     if (need_window_source) {
-        gResizeDeathBounds[0] = (BoxRec) {oldX, oldY, oldX2, oldY2};
+        gResizeDeathBounds[0] = (BoxRec) {
+        oldX, oldY, oldX2, oldY2};
         gResizeDeathPix[0]
             = GetScratchPixmapHeader(pScreen, oldW, oldH,
                                      winRec->win->drawable.depth,
@@ -1100,7 +1101,6 @@ StartFrameResize(WindowPtr pWin, Bool gravity,
     return resize_after;
 }
 
-
 static void
 FinishFrameResize(WindowPtr pWin, Bool gravity, int oldX, int oldY,
                   unsigned int oldW, unsigned int oldH, unsigned int oldBW,
@@ -1148,7 +1148,6 @@ FinishFrameResize(WindowPtr pWin, Bool gravity, int oldX, int oldY,
     }
 }
 
-
 /*
  * RootlessMoveWindow
  *  If kind==VTOther, window border is resizing (and borderWidth is
@@ -1174,7 +1173,8 @@ RootlessMoveWindow(WindowPtr pWin, int x, int y, WindowPtr pSib, VTKind kind)
             oldY = winRec->y;
             RootlessRedisplay(pWin);
             RootlessStartDrawing(pWin);
-        } else {
+        }
+        else {
             RL_DEBUG_MSG("movewindow border resizing ");
 
             oldBW = winRec->borderWidth;
@@ -1186,8 +1186,8 @@ RootlessMoveWindow(WindowPtr pWin, int x, int y, WindowPtr pSib, VTKind kind)
             newBW = wBorderWidth(pWin);
             newX = x;
             newY = y;
-            newW = pWin->drawable.width  + 2*newBW;
-            newH = pWin->drawable.height + 2*newBW;
+            newW = pWin->drawable.width + 2 * newBW;
+            newH = pWin->drawable.height + 2 * newBW;
 
             resize_after = StartFrameResize(pWin, FALSE,
                                             oldX, oldY, oldW, oldH, oldBW,
@@ -1218,7 +1218,8 @@ RootlessMoveWindow(WindowPtr pWin, int x, int y, WindowPtr pSib, VTKind kind)
             SCREENREC(pScreen)->imp->MoveFrame(winRec->wid, pScreen,
                                                x + SCREEN_TO_GLOBAL_X,
                                                y + SCREEN_TO_GLOBAL_Y);
-        } else {
+        }
+        else {
             FinishFrameResize(pWin, FALSE, oldX, oldY, oldW, oldH, oldBW,
                               newX, newY, newW, newH, newBW, resize_after);
         }
@@ -1227,7 +1228,6 @@ RootlessMoveWindow(WindowPtr pWin, int x, int y, WindowPtr pSib, VTKind kind)
     RL_DEBUG_MSG("movewindow end\n");
 }
 
-
 /*
  * RootlessResizeWindow
  *  Note: (x, y, w, h) as passed to this procedure don't match the frame
@@ -1248,8 +1248,8 @@ RootlessResizeWindow(WindowPtr pWin, int x, int y,
     RegionRec saveRoot;
 
     RL_DEBUG_MSG("resizewindow start (win 0x%x) ", pWin);
-    
-    if(pWin->parent) {
+
+    if (pWin->parent) {
         if (winRec) {
             oldBW = winRec->borderWidth;
             oldX = winRec->x;
@@ -1260,8 +1260,8 @@ RootlessResizeWindow(WindowPtr pWin, int x, int y,
             newBW = oldBW;
             newX = x;
             newY = y;
-            newW = w + 2*newBW;
-            newH = h + 2*newBW;
+            newW = w + 2 * newBW;
+            newH = h + 2 * newBW;
 
             resize_after = StartFrameResize(pWin, TRUE,
                                             oldX, oldY, oldW, oldH, oldBW,
@@ -1278,7 +1278,8 @@ RootlessResizeWindow(WindowPtr pWin, int x, int y,
             FinishFrameResize(pWin, TRUE, oldX, oldY, oldW, oldH, oldBW,
                               newX, newY, newW, newH, newBW, resize_after);
         }
-    } else {
+    }
+    else {
         /* Special case for resizing the root window */
         BoxRec box;
 
@@ -1287,8 +1288,10 @@ RootlessResizeWindow(WindowPtr pWin, int x, int y,
         pWin->drawable.width = w;
         pWin->drawable.height = h;
 
-        box.x1 = x; box.y1 = y;
-        box.x2 = x + w; box.y2 = y + h;
+        box.x1 = x;
+        box.y1 = y;
+        box.x2 = x + w;
+        box.y2 = y + h;
         RegionUninit(&pWin->winSize);
         RegionInit(&pWin->winSize, &box, 1);
         RegionCopy(&pWin->borderSize, &pWin->winSize);
@@ -1303,13 +1306,12 @@ RootlessResizeWindow(WindowPtr pWin, int x, int y,
         }
 
         miSendExposures(pWin, &pWin->borderClip,
-                        pWin->drawable.x, pWin->drawable.y);        
+                        pWin->drawable.x, pWin->drawable.y);
     }
 
     RL_DEBUG_MSG("resizewindow end\n");
 }
 
-
 /*
  * RootlessRepositionWindow
  *  Called by the implementation when a window needs to be repositioned to
@@ -1334,7 +1336,6 @@ RootlessRepositionWindow(WindowPtr pWin)
     RootlessReorderWindow(pWin);
 }
 
-
 /*
  * RootlessReparentWindow
  *  Called after a window has been reparented. Generally windows are not
@@ -1353,8 +1354,7 @@ RootlessReparentWindow(WindowPtr pWin, WindowPtr pPriorParent)
 
     /* Check that window is not top-level now, but used to be. */
     if (IsRoot(pWin) || IsRoot(pWin->parent)
-        || IsTopLevel(pWin) || winRec == NULL)
-    {
+        || IsTopLevel(pWin) || winRec == NULL) {
         goto out;
     }
 
@@ -1364,15 +1364,16 @@ RootlessReparentWindow(WindowPtr pWin, WindowPtr pPriorParent)
 
     pTopWin = TopLevelParent(pWin);
     assert(pTopWin != pWin);
-    
+
     pWin->rootlessUnhittable = FALSE;
-    
-    DeleteProperty (serverClient, pWin, xa_native_window_id ());
+
+    DeleteProperty(serverClient, pWin, xa_native_window_id());
 
     if (WINREC(pTopWin) != NULL) {
         /* We're screwed. */
         RootlessDestroyFrame(pWin, winRec);
-    } else {
+    }
+    else {
         if (!pTopWin->realized && pWin->realized) {
             SCREENREC(pScreen)->imp->UnmapFrame(winRec->wid);
         }
@@ -1399,7 +1400,7 @@ RootlessReparentWindow(WindowPtr pWin, WindowPtr pPriorParent)
             winRec->is_reorder_pending = TRUE;
     }
 
-out:
+ out:
     if (SCREENREC(pScreen)->ReparentWindow) {
         SCREEN_UNWRAP(pScreen, ReparentWindow);
         pScreen->ReparentWindow(pWin, pPriorParent);
@@ -1407,20 +1408,19 @@ out:
     }
 }
 
-
 void
-RootlessFlushWindowColormap (WindowPtr pWin)
+RootlessFlushWindowColormap(WindowPtr pWin)
 {
-  RootlessWindowRec *winRec = WINREC (pWin);
-  ScreenPtr pScreen = pWin->drawable.pScreen;
+    RootlessWindowRec *winRec = WINREC(pWin);
+    ScreenPtr pScreen = pWin->drawable.pScreen;
 
-  if (winRec == NULL)
-    return;
+    if (winRec == NULL)
+        return;
 
-  RootlessStopDrawing (pWin, FALSE);
+    RootlessStopDrawing(pWin, FALSE);
 
-  if (SCREENREC(pScreen)->imp->UpdateColormap)
-    SCREENREC(pScreen)->imp->UpdateColormap(winRec->wid, pScreen);
+    if (SCREENREC(pScreen)->imp->UpdateColormap)
+        SCREENREC(pScreen)->imp->UpdateColormap(winRec->wid, pScreen);
 }
 
 /*
@@ -1453,8 +1453,8 @@ RootlessChangeBorderWidth(WindowPtr pWin, unsigned int width)
             newBW = width;
             newX = pWin->drawable.x - newBW;
             newY = pWin->drawable.y - newBW;
-            newW = pWin->drawable.width  + 2*newBW;
-            newH = pWin->drawable.height + 2*newBW;
+            newW = pWin->drawable.width + 2 * newBW;
+            newH = pWin->drawable.height + 2 * newBW;
 
             resize_after = StartFrameResize(pWin, FALSE,
                                             oldX, oldY, oldW, oldH, oldBW,
@@ -1482,131 +1482,132 @@ RootlessChangeBorderWidth(WindowPtr pWin, unsigned int width)
  * (i.e in front of Aqua windows) -- called when X11.app is given focus
  */
 void
-RootlessOrderAllWindows (Bool include_unhitable)
+RootlessOrderAllWindows(Bool include_unhitable)
 {
     int i;
     WindowPtr pWin;
 
     if (windows_hidden)
-        return;    
+        return;
 
     RL_DEBUG_MSG("RootlessOrderAllWindows() ");
     for (i = 0; i < screenInfo.numScreens; i++) {
-      if (screenInfo.screens[i] == NULL) continue;
-      pWin = screenInfo.screens[i]->root;
-      if (pWin == NULL) continue;
-      
-      for (pWin = pWin->firstChild; pWin != NULL; pWin = pWin->nextSib) {
-	if (!pWin->realized) continue;
-	if (RootlessEnsureFrame(pWin) == NULL) continue;
-        if (!include_unhitable && pWin->rootlessUnhittable) continue;
-	RootlessReorderWindow (pWin);
-      }
+        if (screenInfo.screens[i] == NULL)
+            continue;
+        pWin = screenInfo.screens[i]->root;
+        if (pWin == NULL)
+            continue;
+
+        for (pWin = pWin->firstChild; pWin != NULL; pWin = pWin->nextSib) {
+            if (!pWin->realized)
+                continue;
+            if (RootlessEnsureFrame(pWin) == NULL)
+                continue;
+            if (!include_unhitable && pWin->rootlessUnhittable)
+                continue;
+            RootlessReorderWindow(pWin);
+        }
     }
     RL_DEBUG_MSG("RootlessOrderAllWindows() done");
 }
 
 void
-RootlessEnableRoot (ScreenPtr pScreen)
+RootlessEnableRoot(ScreenPtr pScreen)
 {
     WindowPtr pRoot;
+
     pRoot = pScreen->root;
-    
-    RootlessEnsureFrame (pRoot);
+
+    RootlessEnsureFrame(pRoot);
     (*pScreen->ClearToBackground) (pRoot, 0, 0, 0, 0, TRUE);
-    RootlessReorderWindow (pRoot);
+    RootlessReorderWindow(pRoot);
 }
 
 void
-RootlessDisableRoot (ScreenPtr pScreen)
+RootlessDisableRoot(ScreenPtr pScreen)
 {
     WindowPtr pRoot;
     RootlessWindowRec *winRec;
 
     pRoot = pScreen->root;
-    winRec = WINREC (pRoot);
+    winRec = WINREC(pRoot);
 
     if (NULL == winRec)
-	return;
-           
-    RootlessDestroyFrame (pRoot, winRec);
-    DeleteProperty (serverClient, pRoot, xa_native_window_id ());
+        return;
+
+    RootlessDestroyFrame(pRoot, winRec);
+    DeleteProperty(serverClient, pRoot, xa_native_window_id());
 }
 
 void
-RootlessHideAllWindows (void)
+RootlessHideAllWindows(void)
 {
     int i;
     ScreenPtr pScreen;
     WindowPtr pWin;
     RootlessWindowRec *winRec;
-    
+
     if (windows_hidden)
         return;
-    
+
     windows_hidden = TRUE;
-    
-    for (i = 0; i < screenInfo.numScreens; i++)
-    {
+
+    for (i = 0; i < screenInfo.numScreens; i++) {
         pScreen = screenInfo.screens[i];
-	if (pScreen == NULL)
-	    continue;
-	pWin = pScreen->root;
-	if (pWin == NULL)
+        if (pScreen == NULL)
             continue;
-        
-        for (pWin = pWin->firstChild; pWin != NULL; pWin = pWin->nextSib)
-        {
+        pWin = pScreen->root;
+        if (pWin == NULL)
+            continue;
+
+        for (pWin = pWin->firstChild; pWin != NULL; pWin = pWin->nextSib) {
             if (!pWin->realized)
                 continue;
-            
-            RootlessStopDrawing (pWin, FALSE);
-            
-            winRec = WINREC (pWin);
-            if (winRec != NULL)
-            {
-              if (SCREENREC(pScreen)->imp->HideWindow)
-                SCREENREC(pScreen)->imp->HideWindow(winRec->wid);
+
+            RootlessStopDrawing(pWin, FALSE);
+
+            winRec = WINREC(pWin);
+            if (winRec != NULL) {
+                if (SCREENREC(pScreen)->imp->HideWindow)
+                    SCREENREC(pScreen)->imp->HideWindow(winRec->wid);
             }
         }
     }
 }
 
 void
-RootlessShowAllWindows (void)
+RootlessShowAllWindows(void)
 {
     int i;
     ScreenPtr pScreen;
     WindowPtr pWin;
     RootlessWindowRec *winRec;
-    
+
     if (!windows_hidden)
         return;
-    
+
     windows_hidden = FALSE;
-    
-    for (i = 0; i < screenInfo.numScreens; i++)
-    {
+
+    for (i = 0; i < screenInfo.numScreens; i++) {
         pScreen = screenInfo.screens[i];
-	if (pScreen == NULL)
-	    continue;
-	pWin = pScreen->root;
-	if (pWin == NULL)
+        if (pScreen == NULL)
             continue;
-        
-        for (pWin = pWin->firstChild; pWin != NULL; pWin = pWin->nextSib)
-        {
+        pWin = pScreen->root;
+        if (pWin == NULL)
+            continue;
+
+        for (pWin = pWin->firstChild; pWin != NULL; pWin = pWin->nextSib) {
             if (!pWin->realized)
                 continue;
-            
-            winRec = RootlessEnsureFrame (pWin);
+
+            winRec = RootlessEnsureFrame(pWin);
             if (winRec == NULL)
                 continue;
-            
-            RootlessReorderWindow (pWin);
+
+            RootlessReorderWindow(pWin);
         }
-        
-        RootlessScreenExpose (pScreen);
+
+        RootlessScreenExpose(pScreen);
     }
 }
 
@@ -1620,18 +1621,18 @@ RootlessSetPixmapOfAncestors(WindowPtr pWin)
     ScreenPtr pScreen = pWin->drawable.pScreen;
     WindowPtr topWin = TopLevelParent(pWin);
     RootlessWindowRec *topWinRec = WINREC(topWin);
-    
+
     while (pWin->backgroundState == ParentRelative) {
         if (pWin == topWin) {
             // disallow ParentRelative background state on top level
             XID pixel = 0;
+
             ChangeWindowAttributes(pWin, CWBackPixel, &pixel, serverClient);
             RL_DEBUG_MSG("Cleared ParentRelative on 0x%x.\n", pWin);
             break;
         }
-        
+
         pWin = pWin->parent;
         pScreen->SetWindowPixmap(pWin, topWinRec->pixmap);
     }
 }
-
